//! Structures represent corresponding fields in ripple transactions.

pub mod account;
pub mod definition;
pub mod amount;
pub mod path_set;
pub mod hash;
pub mod blob;
pub mod starray;
pub mod stobject;


